%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id$
%%
-module(erl.lang.port).

-export([call/2, call/3, close/1, command/2, connect/2, control/3,
	 get_data/1, info/1, info/2, open/2, set_data/2, to_list/1]).

%% FIXME: Split open/2 into several functions? See below:
%%   Date: Wed, 20 Aug 2003 17:16:29 -0400
%%   From: Vance Shipley <vances@motivity.ca>
%%   To: erlang-questions@erlang.org
%%   Subject: open_port/2 overloading
%%
%%   It is unfortunate that the open_port/2 BIF is overloaded to
%%   handle drivers.  The result is that opening a port always
%%   succeeds:
%%
%%   Erlang (BEAM) emulator version 5.3 [source] [hipe]
%%
%%   Eshell V5.3  (abort with ^G)
%%   1> P = open_port({spawn, 'bogus_drv'}, []).
%%   sh: bogus_drv: not found
%% 			  #Port<0.28>
%%   2> is_port(P).
%%   true
%%
%%   This is because if there is no currently loaded driver with
%%   the name "bogus_drv" it will start a Unix shell to run the
%%   command "bogus_drv".  The shell get's started therefore we
%%   get an opened port.
%%
%%   It would be nice to have an explicit method to open ports on
%%   drivers which would fail appropriately.
%%
%% 	  -Vance


%% @doc Undocumented. Do not use.
call(Port, Operation) ->
    erl.lang.port:call(Port, Operation).    % Built-in function


%% @doc See {@link /kernel/erlang:port_call/3}.
call(Port, Operation, Data) ->
    erl.lang.port:call(Port, Operation, Data).    % Built-in function


%% @doc See {@link /kernel/erlang:port_close/1}.
close(Port) ->
    erl.lang.port:close(Port).    % Built-in function


%% @doc See {@link /kernel/erlang:port_command/2}.
command(Port, Data) ->
    erl.lang.port:command(Port, Data).    % Built-in function


%% @doc See {@link /kernel/erlang:port_connect/2}.
connect(Port, Pid) ->
    erl.lang.port:connect(Port, Pid).    % Built-in function


%% @doc See {@link /kernel/erlang:port_control/3}.
control(Port, Operation, Data) ->
    erl.lang.port:control(Port, Operation, Data).    % Built-in function


%% @doc Undocumented. Do not use.
get_data(Port) -> erl.lang.port:get_data(Port).    % Built-in function


%% @doc Undocumented. Do not use.
info(Port) ->
    erl.lang.port:info(Port).    % Built-in function


%% @doc See {@link /kernel/erlang:port_info/2}.
info(Port, Item) ->
    erl.lang.port:info(Port, Item).    % Built-in function


%% @doc See {@link /kernel/erlang:open_port/2}.
open(Name, Settings) ->
    %% FIXME: open + open_driver? See note above.
    erl.lang.port:open(Name, Settings).    % Built-in function


%% @doc Undocumented. Do not use.
set_data(Port, Data) ->
    erl.lang.port:set_data(Port, Data).    % Built-in function


%% @doc See {@link /kernel/erlang:port_to_list/1}.
to_list(Port) ->
    erl.lang.port:to_list(Port).    % Built-in function
